@@ -26,12 +26,12 @@ use crate::{
     BackendInitInfo, ast, complete, document_link, fileapi, filewatcher, hover, jump, quick_fix,
     rename, scansubs, semantic_token, utils,
 };
-
-pub static BUFFERS_CACHE: LazyLock<Arc<Mutex<HashMap<lsp_types::Url, String>>>> =
+use std::sync::atomic::{AtomicBool, Ordering};
+pub static BUFFERS_CACHE: LazyLock<Arc<Mutex<HashMap<lsp_types::Uri, String>>>> =
     LazyLock::new(|| Arc::new(Mutex::new(HashMap::new())));
 
 static CLIENT_CAPABILITIES: RwLock<Option<TextDocumentClientCapabilities>> = RwLock::new(None);
-
+static ENABLE_SNIPPET: AtomicBool = AtomicBool::new(false);
 fn set_client_text_document(text_document: Option<TextDocumentClientCapabilities>) {
     let mut data = CLIENT_CAPABILITIES.write().unwrap();
     *data = text_document;
@@ -42,7 +42,14 @@ pub fn get_client_capabilities() -> Option<TextDocumentClientCapabilities> {
     data.clone()
 }
 
-pub fn client_support_snippet() -> bool {
+fn init_snippet_setting(use_snippet: bool) {
+    ENABLE_SNIPPET.store(use_snippet, Ordering::Relaxed);
+}
+
+pub fn to_use_snippet() -> bool {
+    if !ENABLE_SNIPPET.load(Ordering::Relaxed) {
+        return false;
+    }
     match get_client_capabilities() {
         Some(c) => c
             .completion
@@ -77,7 +84,7 @@ impl Backend {
             .all(|component| component != Component::ParentDir)
     }
 
-    async fn publish_diagnostics(&self, uri: Url, context: String, lint_info: LintConfigInfo) {
+    async fn publish_diagnostics(&self, uri: Uri, context: String, lint_info: LintConfigInfo) {
         let Ok(file_path) = uri.to_file_path() else {
             tracing::error!("Cannot transport {uri:?} to file_path");
             self.client
@@ -145,7 +152,6 @@ impl Backend {
     }
 }
 
-#[tower_lsp::async_trait]
 impl LanguageServer for Backend {
     async fn initialize(&self, initial: InitializeParams) -> Result<InitializeResult> {
         let initial_config: Config = initial
@@ -153,6 +159,8 @@ impl LanguageServer for Backend {
             .and_then(|value| serde_json::from_value(value).unwrap_or(None))
             .unwrap_or_default();
 
+        init_snippet_setting(initial_config.use_snippets());
+
         let do_format = initial_config.is_format_enabled();
 
         let scan_cmake_in_package = initial_config.is_scan_cmake_in_package();
@@ -561,7 +569,7 @@ impl LanguageServer for Backend {
         self.client
             .log_message(
                 MessageType::INFO,
-                &format!("update file: {}", input.text_document.uri),
+                &format!("update file: {:?}", input.text_document.uri),
             )
             .await;
     }
